﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

using C1.Silverlight.Pdf;
using System.Reflection;

namespace C1.Silverlight.FlexGrid.PrintPreview
{
    public partial class PageSetupWindow : C1Window
    {
        private PageSettings _pageSettings;
        private const int DPI = 72;

        public PageSetupWindow(PageSettings pageSettings)
        {
            InitializeComponent();
            // init paperkind combobox
            SetupPaperKind();

            // set local settings
            PageSettings = pageSettings;  
            
        }    

        public PageSettings PageSettings
        {
            get
            {
               // get page settings for print preview dialog
                _pageSettings.Margins = new Thickness(ToPixels(nbLeftMargin.Value),
                    ToPixels(nbTopMargin.Value),
                    ToPixels(nbRightMargin.Value),
                    ToPixels(nbBottomMargin.Value));
                _pageSettings.ScaleMode = GetScaleMode(comboScaleMode.SelectedIndex);
                _pageSettings.IsLandscape = (bool)radioLandscape.IsChecked ? true : false;
                _pageSettings.PaperKind = GetPaperKind(comboPaperKind.SelectedItem.ToString());
                _pageSettings.CustomPageSize = new Size(ToPixels(nbCustomPageWidth.Value), ToPixels(nbCustomPageHeight.Value));
                _pageSettings.HeaderLeftText = txtHeaderLeft.Text;
                _pageSettings.HeaderRightText = txtHeaderRight.Text;
                _pageSettings.ShowHeaderSeparator = (bool)chkShowHeaderSeparator.IsChecked;
                _pageSettings.FooterLeftText = txtFooterLeft.Text;
                _pageSettings.FooterRightText = txtFooterRight.Text;
                _pageSettings.ShowFooterSeparator = (bool)chkShowFooterSeparator.IsChecked;
                return _pageSettings;
            }
            set
            {
                // initialize page settings
                _pageSettings = value;

                // populate UI controls
                nbBottomMargin.Value = ToInches(value.BottomMargin);
                nbTopMargin.Value = ToInches(value.TopMargin);
                nbRightMargin.Value = ToInches(value.RightMargin);
                nbLeftMargin.Value = ToInches(value.LeftMargin);
                if (value.ScaleMode == ScaleMode.ActualSize)
                {
                    comboScaleMode.SelectedIndex = 0;
                }
                else if (value.ScaleMode == ScaleMode.PageWidth)
                {
                    comboScaleMode.SelectedIndex = 1;
                }
                else
                {
                    comboScaleMode.SelectedIndex = 2;
                }

                radioLandscape.IsChecked = value.IsLandscape;
                comboPaperKind.SelectedItem = value.PaperKind.ToString();
                nbCustomPageWidth.Value = ToInches(value.CustomPageSize.Width);
                nbCustomPageHeight.Value = ToInches(value.CustomPageSize.Height);
                txtHeaderLeft.Text = value.HeaderLeftText;
                txtHeaderRight.Text = value.HeaderRightText;
                txtFooterLeft.Text = value.FooterLeftText;
                txtFooterRight.Text = value.FooterRightText;
                chkShowHeaderSeparator.IsChecked = value.ShowHeaderSeparator;
                chkShowFooterSeparator.IsChecked = value.ShowFooterSeparator;

            }
        }

        /// <summary>
        /// Populates comboPaperKind with the values from the C1Pdf.PaperKind enum
        /// </summary>
        private void SetupPaperKind()
        {
            List<string> paperKinds = new List<string>();

            Type typePaperKind = typeof(PaperKind);
            FieldInfo[] paperKindValues = typePaperKind.GetFields(BindingFlags.Public | BindingFlags.Static);
            foreach (var kind in paperKindValues)
            {
                paperKinds.Add(kind.GetValue(null).ToString());
            }
            comboPaperKind.ItemsSource = paperKinds;
        }

        /// <summary>
        /// Returns the PaperKind given a matching string value
        /// </summary>
        /// <param name="kind">Paper kind name</param>
        /// <returns></returns>
        private PaperKind GetPaperKind(string kind)
        {
            PaperKind pk = (PaperKind)Enum.Parse(typeof(PaperKind), kind, true);
            return pk;
        }

        /// <summary>
        /// Returns the ScaleMode given an index associated with the ScaleMode combobox
        /// </summary>
        /// <param name="index"></param>
        /// <returns></returns>
        private ScaleMode GetScaleMode(int index)
        {
            if (index == 0)
                return ScaleMode.ActualSize;
            else if (index == 1)
                return ScaleMode.PageWidth;
            else
                return ScaleMode.SinglePage;
        }

        /// <summary>
        /// Converts pixels (dots) to inches
        /// </summary>
        /// <param name="pixels"></param>
        /// <returns></returns>
        private double ToInches(double pixels)
        {
            return pixels / DPI;
        }

        /// <summary>
        /// Converts inches to pixels (dots)
        /// </summary>
        /// <param name="inches"></param>
        /// <returns></returns>
        private double ToPixels(double inches)
        {
            return inches * DPI;
        }

        private void btnOK_Click(object sender, RoutedEventArgs e)
        {      
            this.DialogResult = MessageBoxResult.OK;
        }

        private void btnCancel_Click(object sender, RoutedEventArgs e)
        {
            this.DialogResult = MessageBoxResult.Cancel;
        }

        private void comboPaperKind_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (comboPaperKind.SelectedIndex == 0)
            {
                nbCustomPageWidth.IsEnabled = true;
                nbCustomPageHeight.IsEnabled = true;
                nbCustomPageWidth.Value = 8.5;
                nbCustomPageHeight.Value = 11;
            }
            else
            {
                nbCustomPageWidth.IsEnabled = false;
                nbCustomPageHeight.IsEnabled = false;
                nbCustomPageWidth.Value = 0;
                nbCustomPageHeight.Value = 0;
            }
        }
    }
}
