﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using C1.Silverlight.Pdf;
using C1.Silverlight.FlexGrid;
using System.IO;

namespace C1.Silverlight.FlexGrid.PrintPreview
{
    public partial class PrintPreviewWindow : C1Window
    {
        private C1FlexGrid _flexGrid;
        private PageSettings _pageSettings;
        
        public PrintPreviewWindow(C1FlexGrid grid, PageSettings settings)
        {
            InitializeComponent();
            _flexGrid = grid;
            _pageSettings = settings;

            UpdateDocument(settings);
        }     

        /// <summary>
        /// Loads the passed document into the viewer
        /// </summary>
        /// <param name="doc">The C1PdfDocument used for previewing</param>
        public void LoadDocument(C1PdfDocument doc)
        {
            if (doc != null)
            {
                MemoryStream ms = new MemoryStream();
                doc.Save(ms);
                ms.Seek(0, SeekOrigin.Begin);
                pdfViewer.LoadDocument(ms);
            }
        }

        private void UpdateDocument(PageSettings ps)
        {
            
            LoadDocument(_flexGrid.ToPdf(ps));
        }

        private void btnPageSetup_Click(object sender, RoutedEventArgs e)
        {
            PageSetupWindow psw = new PageSetupWindow(_pageSettings);
            psw.Closed += new EventHandler(psw_Closed);
            psw.CenterOnScreen();
            psw.ShowModal();
        }

        void psw_Closed(object sender, EventArgs e)
        {
            PageSetupWindow psw = (PageSetupWindow)sender;
            if (psw.DialogResult == MessageBoxResult.OK)
            {
                _pageSettings = psw.PageSettings;
                UpdateDocument(_pageSettings);
            }
        }

        
        
    }
}
